company

# XMLRésuméLibrary: User Guide

clearances | Element Reference | contact

## Name

company — The name of a company

Deprecated

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

### Important

This element is deprecated as of XML Résumé Library version 1.3.3. It should not be used.

### Parents

`company` may be contained in these elements: None

## See Also

`institution`, `organization`.

## Examples

None.

clearances | Element Reference | contact